@@ -53,20 +53,19 @@ OdrsReviewsBackend::OdrsReviewsBackend()
     fetchRatings();
 }
 
-OdrsReviewsBackend::~OdrsReviewsBackend() noexcept
+OdrsReviewsBackend::~OdrsReviewsBackend()
 {
-    qDeleteAll(m_ratings);
 }
 
 void OdrsReviewsBackend::fetchRatings()
 {
     bool fetchRatings = false;
-    const QUrl ratingsUrl(QStringLiteral(APIURL "/ratings"));
-    const QUrl fileUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/ratings/ratings"));
+    const QUrl ratingsUrl(QLatin1StringView(APIURL "/ratings"));
+    const QUrl fileUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1StringView("/ratings/ratings"));
     const QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation));
 
     // Create $HOME/.cache/discover/ratings folder
-    cacheDir.mkpath(QStringLiteral("ratings"));
+    cacheDir.mkpath(QLatin1StringView("ratings"));
 
     if (QFileInfo::exists(fileUrl.toLocalFile())) {
         QFileInfo file(fileUrl.toLocalFile());
@@ -81,7 +80,7 @@ void OdrsReviewsBackend::fetchRatings()
     qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Fetch ratings:" << fetchRatings;
     if (fetchRatings) {
         setFetching(true);
-        KIO::FileCopyJob *getJob = KIO::file_copy(ratingsUrl, fileUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
+        auto getJob = KIO::file_copy(ratingsUrl, fileUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
         connect(getJob, &KIO::FileCopyJob::result, this, &OdrsReviewsBackend::ratingsFetched);
     } else {
         parseRatings();
@@ -114,10 +113,10 @@ static QString osName()
 
 static QString userHash()
 {
-    QString machineId;
-    QFile file(QStringLiteral("/etc/machine-id"));
+    QByteArray machineId;
+    QFile file(QLatin1StringView("/etc/machine-id"));
     if (file.open(QIODevice::ReadOnly)) {
-        machineId = QString::fromUtf8(file.readAll());
+        machineId = file.readAll();
         file.close();
     }
 
@@ -125,37 +124,37 @@ static QString userHash()
         return QString();
     }
 
-    QString salted = QStringLiteral("gnome-software[%1:%2]").arg(KUser().loginName(), machineId);
-    return QString::fromUtf8(QCryptographicHash::hash(salted.toUtf8(), QCryptographicHash::Sha1).toHex());
+    const QByteArray salted = QByteArray("gnome-software[") + KUser().loginName().toUtf8() + ':' + machineId + ']';
+    return QString::fromUtf8(QCryptographicHash::hash(salted, QCryptographicHash::Sha1).toHex());
 }
 
-void OdrsReviewsBackend::fetchReviews(AbstractResource *app, int page)
+void OdrsReviewsBackend::fetchReviews(AbstractResource *resource, int page)
 {
-    if (app->appstreamId().isEmpty()) {
+    if (resource->appstreamId().isEmpty()) {
         return;
     }
     Q_UNUSED(page)
-    QString version = app->isInstalled() ? app->installedVersion() : app->availableVersion();
+    QString version = resource->isInstalled() ? resource->installedVersion() : resource->availableVersion();
     if (version.isEmpty()) {
-        version = QStringLiteral("unknown");
+        version = QLatin1StringView("unknown");
     }
     setFetching(true);
 
     const QJsonDocument document(QJsonObject{
-        {QStringLiteral("app_id"), app->appstreamId()},
-        {QStringLiteral("distro"), osName()},
-        {QStringLiteral("user_hash"), userHash()},
-        {QStringLiteral("version"), version},
-        {QStringLiteral("locale"), QLocale::system().name()},
-        {QStringLiteral("limit"), -1},
+        {QLatin1StringView("app_id"), resource->appstreamId()},
+        {QLatin1StringView("distro"), osName()},
+        {QLatin1StringView("user_hash"), userHash()},
+        {QLatin1StringView("version"), version},
+        {QLatin1StringView("locale"), QLocale::system().name()},
+        {QLatin1StringView("limit"), -1},
     });
 
     const auto json = document.toJson(QJsonDocument::Compact);
     QNetworkRequest request(QUrl(QStringLiteral(APIURL "/fetch")));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json; charset=utf-8"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1StringView("application/json; charset=utf-8"));
     request.setHeader(QNetworkRequest::ContentLengthHeader, json.size());
-    // Store reference to the app for which we request reviews
-    request.setOriginatingObject(app);
+    // Store reference to the resource for which we request reviews
+    request.setOriginatingObject(resource);
 
     auto reply = nam()->post(request, json);
     connect(reply, &QNetworkReply::finished, this, &OdrsReviewsBackend::reviewsFetched);
@@ -163,7 +162,7 @@ void OdrsReviewsBackend::fetchReviews(AbstractResource *app, int page)
 
 void OdrsReviewsBackend::reviewsFetched()
 {
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    const auto reply = qobject_cast<QNetworkReply *>(sender());
     QScopedPointer<QNetworkReply, QScopedPointerDeleteLater> replyPtr(reply);
     const QByteArray data = reply->readAll();
     const auto networkError = reply->error();
@@ -178,35 +177,35 @@ void OdrsReviewsBackend::reviewsFetched()
     QJsonParseError error;
     const QJsonDocument document = QJsonDocument::fromJson(data, &error);
     if (error.error) {
-        qWarning() << "OdrsReviewsBackend: Error parsing reviews:" << reply->url() << error.errorString();
+        qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Error parsing reviews:" << reply->url() << error.errorString();
     }
 
-    AbstractResource *resource = qobject_cast<AbstractResource *>(reply->request().originatingObject());
+    const auto resource = qobject_cast<AbstractResource *>(reply->request().originatingObject());
     Q_ASSERT(resource);
     parseReviews(document, resource);
 }
 
-Rating *OdrsReviewsBackend::ratingForApplication(AbstractResource *app) const
+Rating OdrsReviewsBackend::ratingForApplication(AbstractResource *resource) const
 {
-    if (app->appstreamId().isEmpty()) {
-        return nullptr;
+    if (resource->appstreamId().isEmpty()) {
+        return {};
     }
 
-    return m_ratings[app->appstreamId()];
+    return m_ratings[resource->appstreamId()];
 }
 
 void OdrsReviewsBackend::submitUsefulness(Review *review, bool useful)
 {
     const QJsonDocument document(QJsonObject{
-        {QStringLiteral("app_id"), review->applicationName()},
-        {QStringLiteral("user_skey"), review->getMetadata(QStringLiteral("ODRS::user_skey")).toString()},
-        {QStringLiteral("user_hash"), userHash()},
-        {QStringLiteral("distro"), osName()},
-        {QStringLiteral("review_id"), QJsonValue(double(review->id()))}, // if we really need uint64 we should get it in QJsonValue
+        {QLatin1StringView("app_id"), review->applicationName()},
+        {QLatin1StringView("user_skey"), review->getMetadata(QLatin1StringView("ODRS::user_skey")).toString()},
+        {QLatin1StringView("user_hash"), userHash()},
+        {QLatin1StringView("distro"), osName()},
+        {QLatin1StringView("review_id"), QJsonValue(double(review->id()))}, // if we really need uint64 we should get it in QJsonValue
     });
 
     QNetworkRequest request(QUrl(QStringLiteral(APIURL) + (useful ? QLatin1String("/upvote") : QLatin1String("/downvote"))));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json; charset=utf-8"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1StringView("application/json; charset=utf-8"));
     request.setHeader(QNetworkRequest::ContentLengthHeader, document.toJson().size());
 
     auto reply = nam()->post(request, document.toJson());
@@ -215,12 +214,12 @@ void OdrsReviewsBackend::submitUsefulness(Review *review, bool useful)
 
 void OdrsReviewsBackend::usefulnessSubmitted()
 {
-    QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
+    const auto reply = qobject_cast<QNetworkReply *>(sender());
     const auto networkError = reply->error();
     if (networkError == QNetworkReply::NoError) {
-        qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Usefulness submitted";
+        qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Usefulness submitted successfully";
     } else {
-        qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Failed to submit usefulness: " << reply->errorString();
+        qCWarning(LIBDISCOVER_LOG).noquote() << "OdrsReviewsBackend: Failed to submit usefulness:" << reply->errorString();
         Q_EMIT error(i18n("Error while submitting usefulness: %1", reply->errorString()));
     }
     reply->deleteLater();
@@ -231,34 +230,38 @@ QString OdrsReviewsBackend::userName() const
     return KUser().property(KUser::FullName).toString();
 }
 
-void OdrsReviewsBackend::sendReview(AbstractResource *res, const QString &summary, const QString &description, const QString &rating, const QString &userName)
+void OdrsReviewsBackend::sendReview(AbstractResource *resource,
+                                    const QString &summary,
+                                    const QString &reviewText,
+                                    const QString &rating,
+                                    const QString &userName)
 {
-    Q_ASSERT(res);
+    Q_ASSERT(resource);
     QJsonObject map = {
-        {QStringLiteral("app_id"), res->appstreamId()},
-        {QStringLiteral("user_skey"), res->getMetadata(QStringLiteral("ODRS::user_skey")).toString()},
-        {QStringLiteral("user_hash"), userHash()},
-        {QStringLiteral("version"), res->isInstalled() ? res->installedVersion() : res->availableVersion()},
-        {QStringLiteral("locale"), QLocale::system().name()},
-        {QStringLiteral("distro"), osName()},
-        {QStringLiteral("user_display"), QJsonValue::fromVariant(userName)},
-        {QStringLiteral("summary"), summary},
-        {QStringLiteral("description"), description},
-        {QStringLiteral("rating"), rating.toInt() * 10},
+        {QLatin1StringView("app_id"), resource->appstreamId()},
+        {QLatin1StringView("user_skey"), resource->getMetadata(QLatin1StringView("ODRS::user_skey")).toString()},
+        {QLatin1StringView("user_hash"), userHash()},
+        {QLatin1StringView("version"), resource->isInstalled() ? resource->installedVersion() : resource->availableVersion()},
+        {QLatin1StringView("locale"), QLocale::system().name()},
+        {QLatin1StringView("distro"), osName()},
+        {QLatin1StringView("user_display"), QJsonValue::fromVariant(userName)},
+        {QLatin1StringView("summary"), summary},
+        {QLatin1StringView("description"), reviewText},
+        {QLatin1StringView("rating"), rating.toInt() * 10},
     };
 
     const QJsonDocument document(map);
 
-    QNetworkAccessManager *accessManager = nam();
+    const auto accessManager = nam();
     QNetworkRequest request(QUrl(QStringLiteral(APIURL "/submit")));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json; charset=utf-8"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1StringView("application/json; charset=utf-8"));
     request.setHeader(QNetworkRequest::ContentLengthHeader, document.toJson().size());
 
     // Store what we need so we can immediately show our review once it is submitted
     // Use review_id 0 for now as odrs starts numbering from 1 and once reviews are re-downloaded we get correct id
-    map.insert(QStringLiteral("review_id"), 0);
-    res->addMetadata(QStringLiteral("ODRS::review_map"), map);
-    request.setOriginatingObject(res);
+    map.insert(QLatin1StringView("review_id"), 0);
+    resource->addMetadata(QLatin1StringView("ODRS::review_map"), map);
+    request.setOriginatingObject(resource);
 
     accessManager->post(request, document.toJson());
     connect(accessManager, &QNetworkAccessManager::finished, this, &OdrsReviewsBackend::reviewSubmitted);
@@ -268,18 +271,19 @@ void OdrsReviewsBackend::reviewSubmitted(QNetworkReply *reply)
 {
     const auto networkError = reply->error();
     if (networkError == QNetworkReply::NoError) {
-        AbstractResource *resource = qobject_cast<AbstractResource *>(reply->request().originatingObject());
+        const auto resource = qobject_cast<AbstractResource *>(reply->request().originatingObject());
         Q_ASSERT(resource);
         qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Review submitted for" << resource;
         if (resource) {
-            const QJsonDocument document({resource->getMetadata(QStringLiteral("ODRS::review_map")).toObject()});
+            const QJsonDocument document({resource->getMetadata(QLatin1StringView("ODRS::review_map")).toObject()});
             parseReviews(document, resource);
         } else {
             qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Failed to submit review: missing object";
         }
     } else {
+        qCWarning(LIBDISCOVER_LOG).noquote() << "OdrsReviewsBackend: Failed to submit review:" << reply->error() << reply->errorString()
+                                             << reply->rawHeaderPairs();
         Q_EMIT error(i18n("Error while submitting review: %1", reply->errorString()));
-        qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Failed to submit review:" << reply->errorString();
     }
     reply->deleteLater();
 }
@@ -288,12 +292,12 @@ void OdrsReviewsBackend::parseRatings()
 {
     auto fw = new QFutureWatcher<QJsonDocument>(this);
     connect(fw, &QFutureWatcher<QJsonDocument>::finished, this, [this, fw] {
-        const QJsonDocument jsonDocument = fw->result();
+        const auto jsonDocument = fw->result();
         fw->deleteLater();
-        const QJsonObject jsonObject = jsonDocument.object();
+        const auto jsonObject = jsonDocument.object();
         m_ratings.reserve(jsonObject.size());
         for (auto it = jsonObject.begin(); it != jsonObject.end(); it++) {
-            QJsonObject appJsonObject = it.value().toObject();
+            const auto appJsonObject = it.value().toObject();
 
             const int ratingCount = appJsonObject.value(QLatin1String("total")).toInt();
             int ratingMap[] = {
@@ -305,19 +309,20 @@ void OdrsReviewsBackend::parseRatings()
                 appJsonObject.value(QLatin1String("star5")).toInt(),
             };
 
-            Rating *rating = new Rating(it.key(), ratingCount, ratingMap);
+            const auto rating = Rating(it.key(), ratingCount, ratingMap);
             m_ratings.insert(it.key(), rating);
 
-            const auto finder = [rating](Rating *r) {
-                return r->ratingPoints() < rating->ratingPoints();
+            const auto finder = [&rating](const Rating &review) {
+                return review.ratingPoints() < rating.ratingPoints();
             };
             const auto topIt = std::find_if(m_top.begin(), m_top.end(), finder);
             if (topIt == m_top.end()) {
                 if (m_top.size() < 25) {
                     m_top.append(rating);
                 }
-            } else
+            } else {
                 m_top.insert(topIt, rating);
+            }
             if (m_top.size() > 25) {
                 m_top.resize(25);
             }
@@ -325,16 +330,16 @@ void OdrsReviewsBackend::parseRatings()
         Q_EMIT ratingsReady();
     });
     fw->setFuture(QtConcurrent::run([] {
-        QFile ratingsDocument(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QStringLiteral("/ratings/ratings"));
+        QFile ratingsDocument(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1StringView("/ratings/ratings"));
         if (!ratingsDocument.open(QIODevice::ReadOnly)) {
-            qWarning() << "OdrsReviewsBackend: Could not open file" << ratingsDocument.fileName();
+            qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Could not open file" << ratingsDocument.fileName();
             return QJsonDocument::fromJson({});
         }
 
         QJsonParseError error;
         const auto ret = QJsonDocument::fromJson(ratingsDocument.readAll(), &error);
         if (error.error) {
-            qWarning() << "OdrsReviewsBackend: Error parsing ratings: " << ratingsDocument.errorString() << error.errorString();
+            qCWarning(LIBDISCOVER_LOG) << "OdrsReviewsBackend: Error parsing ratings:" << ratingsDocument.errorString() << error.errorString();
         }
         return ret;
     }));
@@ -348,18 +353,18 @@ void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractRes
         return;
     }
 
-    QJsonArray reviews = document.array();
+    const auto reviews = document.array();
     if (!reviews.isEmpty()) {
-        QVector<ReviewPtr> reviewList;
-        for (auto it = reviews.begin(); it != reviews.end(); it++) {
-            const QJsonObject review = it->toObject();
+        QList<ReviewPtr> reviewsList;
+        for (const auto &it : reviews) {
+            const QJsonObject review = it.toObject();
             if (!review.isEmpty()) {
                 // Same ranking algorythm Gnome Software uses
-                const int usefulFavorable = review.value(QStringLiteral("karma_up")).toInt();
-                const int usefulNegative = review.value(QStringLiteral("karma_down")).toInt();
+                const int usefulFavorable = review.value(QLatin1StringView("karma_up")).toInt();
+                const int usefulNegative = review.value(QLatin1StringView("karma_down")).toInt();
                 const int usefulTotal = usefulFavorable + usefulNegative;
 
-                qreal usefulWilson = 0.f;
+                qreal usefulWilson = 0.0;
 
                 /* from http://www.evanmiller.org/how-not-to-sort-by-average-rating.html */
                 if (usefulFavorable > 0 || usefulNegative > 0) {
@@ -367,19 +372,19 @@ void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractRes
                                     - 1.96 * sqrt((usefulFavorable * usefulNegative) / qreal(usefulFavorable + usefulNegative) + 0.9604)
                                         / (usefulFavorable + usefulNegative))
                         / (1 + 3.8416 / (usefulFavorable + usefulNegative));
-                    usefulWilson *= 100.f;
+                    usefulWilson *= 100.0;
                 }
 
                 QDateTime dateTime;
-                dateTime.setSecsSinceEpoch(review.value(QStringLiteral("date_created")).toInt());
+                dateTime.setSecsSinceEpoch(review.value(QLatin1StringView("date_created")).toInt());
 
                 // If there is no score or the score is the same, base on the age
-                QDateTime currentDateTime = QDateTime::currentDateTime();
-                qreal totalDays = dateTime.daysTo(currentDateTime);
+                const auto currentDateTime = QDateTime::currentDateTime();
+                const auto totalDays = static_cast<qreal>(dateTime.daysTo(currentDateTime));
 
                 // use also the longest common subsequence of the version string to compute relevance
-                const QString reviewVersion = review.value(QStringLiteral("version")).toString();
-                const QString availableVersion = resource->availableVersion();
+                const auto reviewVersion = review.value(QLatin1StringView("version")).toString();
+                const auto availableVersion = resource->availableVersion();
                 qreal versionScore = 0;
                 const int minLength = std::min(reviewVersion.length(), availableVersion.length());
                 if (minLength > 0) {
@@ -393,50 +398,51 @@ void OdrsReviewsBackend::parseReviews(const QJsonDocument &document, AbstractRes
                     versionScore = versionScore / qreal(std::max(reviewVersion.length(), availableVersion.length()) - 1);
                 }
 
-                // Very random heuristic which weights usefulness with age and versioin similarity. Don't penalise usefulness more than 6 months
+                // Very random heuristic which weights usefulness with age and version similarity. Don't penalize usefulness more than 6 months
                 usefulWilson = versionScore + 1.0 / std::max(1.0, totalDays) + usefulWilson / std::clamp(totalDays, 1.0, 93.0);
 
-                ReviewPtr r(new Review(review.value(QStringLiteral("app_id")).toString(),
+                const bool shouldShow = usefulFavorable >= usefulNegative * 2 && review.value(QLatin1StringView("reported")).toInt() < 4;
+                ReviewPtr r(new Review(review.value(QLatin1StringView("app_id")).toString(),
                                        resource->packageName(),
-                                       review.value(QStringLiteral("locale")).toString(),
-                                       review.value(QStringLiteral("summary")).toString(),
-                                       review.value(QStringLiteral("description")).toString(),
-                                       review.value(QStringLiteral("user_display")).toString(),
+                                       review.value(QLatin1StringView("locale")).toString(),
+                                       review.value(QLatin1StringView("summary")).toString(),
+                                       review.value(QLatin1StringView("description")).toString(),
+                                       review.value(QLatin1StringView("user_display")).toString(),
                                        dateTime,
-                                       usefulFavorable >= usefulNegative * 2 || review.value(QStringLiteral("reported")).toInt() > 4,
-                                       review.value(QStringLiteral("review_id")).toInt(),
-                                       review.value(QStringLiteral("rating")).toInt() / 10,
+                                       shouldShow,
+                                       review.value(QLatin1StringView("review_id")).toInt(),
+                                       review.value(QLatin1StringView("rating")).toInt() / 10,
                                        usefulTotal,
                                        usefulFavorable,
                                        usefulWilson,
                                        reviewVersion));
                 // We can also receive just a json with app name and user info so filter these out as there is no review
                 if (!r->summary().isEmpty() && !r->reviewText().isEmpty()) {
-                    reviewList << r;
+                    reviewsList.append(r);
                     // Needed for submitting usefulness
-                    r->addMetadata(QStringLiteral("ODRS::user_skey"), review.value(QStringLiteral("user_skey")).toString());
+                    r->addMetadata(QLatin1StringView("ODRS::user_skey"), review.value(QLatin1StringView("user_skey")).toString());
                 }
 
                 // We should get at least user_skey needed for posting reviews
-                resource->addMetadata(QStringLiteral("ODRS::user_skey"), review.value(QStringLiteral("user_skey")).toString());
+                resource->addMetadata(QLatin1StringView("ODRS::user_skey"), review.value(QLatin1StringView("user_skey")).toString());
             }
         }
 
-        Q_EMIT reviewsReady(resource, reviewList, false);
+        Q_EMIT reviewsReady(resource, reviewsList, false);
     }
 }
 
-bool OdrsReviewsBackend::isResourceSupported(AbstractResource *res) const
+bool OdrsReviewsBackend::isResourceSupported(AbstractResource *resource) const
 {
-    return !res->appstreamId().isEmpty();
+    return !resource->appstreamId().isEmpty();
 }
 
-void OdrsReviewsBackend::emitRatingFetched(AbstractResourcesBackend *b, const QList<AbstractResource *> &resources) const
+void OdrsReviewsBackend::emitRatingFetched(AbstractResourcesBackend *backend, const QList<AbstractResource *> &resources) const
 {
-    b->emitRatingsReady();
-    for (AbstractResource *res : resources) {
-        if (m_ratings.contains(res->appstreamId())) {
-            Q_EMIT res->ratingFetched();
+    backend->emitRatingsReady();
+    for (const auto resource : resources) {
+        if (m_ratings.contains(resource->appstreamId())) {
+            Q_EMIT resource->ratingFetched();
         }
     }
 }
@@ -444,7 +450,9 @@ void OdrsReviewsBackend::emitRatingFetched(AbstractResourcesBackend *b, const QL
 QNetworkAccessManager *OdrsReviewsBackend::nam()
 {
     if (!m_delayedNam) {
-        m_delayedNam = new CachedNetworkAccessManager(QStringLiteral("odrs"), this);
+        m_delayedNam = new CachedNetworkAccessManager(QLatin1StringView("odrs"), this);
     }
     return m_delayedNam;
 }
+
+#include "moc_OdrsReviewsBackend.cpp"
