@@ -253,7 +253,8 @@ bool RpmOstreeBackend::hasExternalTransaction()
 void RpmOstreeBackend::checkForUpdates()
 {
     if (!m_currentlyBootedDeployment) {
-        qInfo() << "rpm-ostree-backend: Called checkForUpdates before the backend is done getting deployments";
+        // Should never happen
+        qWarning() << "rpm-ostree-backend: Called checkForUpdates before the backend is done getting deployments. File a bug to your distribution.";
         return;
     }
 
@@ -431,7 +432,7 @@ void RpmOstreeBackend::foundNewMajorVersion(const QString &newMajorVersion)
 
     // Look for an existing updated deployment or a pending deployment for the
     // current version
-    QString newVersion = m_currentlyBootedDeployment->getNewVersion();
+    QString newVersion = m_currentlyBootedDeployment->availableVersion();
     iterator = QVectorIterator<RpmOstreeResource *>(m_resources);
     while (iterator.hasNext()) {
         RpmOstreeResource *deployment = iterator.next();
@@ -601,3 +602,4 @@ void RpmOstreeBackend::setFetching(bool fetching)
 }
 
 #include "RpmOstreeBackend.moc"
+#include "moc_RpmOstreeBackend.cpp"
