@@ -211,14 +211,21 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
             const QJsonDocument jsonDocument = QJsonDocument::fromJson(m_stdout);
             if (!jsonDocument.isObject()) {
                 qWarning() << "rpm-ostree-backend: Could not parse output as JSON:" << m_prog << m_args;
+                setStatus(Status::DoneWithErrorStatus);
                 return;
             }
 
-            // Get the version stored in .Labels.version
-            const QString newVersion = jsonDocument.object().value(QLatin1String("Labels")).toObject().value(QLatin1String("version")).toString();
+            // Get the version stored in 'org.opencontainers.image.version' label
+            QString newVersion =
+                jsonDocument.object().value(QLatin1String("Labels")).toObject().value(QLatin1String("org.opencontainers.image.version")).toString();
             if (newVersion.isEmpty()) {
-                qInfo() << "rpm-ostree-backend: Could not get the version from the container labels";
-                return;
+                // Check the 'version' label for compatibility with older rpm-ostree releases (< v2024.03)
+                newVersion = jsonDocument.object().value(QLatin1String("Labels")).toObject().value(QLatin1String("version")).toString();
+                if (newVersion.isEmpty()) {
+                    qWarning() << "rpm-ostree-backend: Could not get the version from the container labels";
+                    setStatus(Status::DoneWithErrorStatus);
+                    return;
+                }
             }
 
             QVersionNumber newVersionNumber = QVersionNumber::fromString(newVersion);
@@ -233,6 +240,8 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
             // Should never happen
             qWarning() << "rpm-ostree-backend: Error: Unknown resource format. Please file a bug.";
             passiveMessage(i18n("rpm-ostree-backend: Error: Unknown resource format. Please file a bug."));
+            setStatus(Status::DoneWithErrorStatus);
+            return;
         }
 
         // Always tell the backend to look for a new major version
@@ -258,7 +267,7 @@ void RpmOstreeTransaction::processCommand(int exitCode, QProcess::ExitStatus exi
     default:
         // This should never happen
         qWarning() << "rpm-ostree-backend: Error: Unknown operation requested. Please file a bug.";
-        passiveMessage(i18n("rpm-ostree-backend: Error: Unknown operation requested. Please file a bug."));
+        setStatus(Status::DoneStatus);
     }
     setStatus(Status::DoneStatus);
 }
@@ -384,13 +393,13 @@ QString RpmOstreeTransaction::name() const
         return i18n("Checking for a system update");
         break;
     case Operation::DownloadOnly:
-        return i18n("Downloading system update");
+        return i18n("Downloading system update. Please be patient as progress is not reported.");
         break;
     case Operation::Update:
-        return i18n("Updating the system");
+        return i18n("Updating the system. Please be patient as progress is not reported.");
         break;
     case Operation::Rebase:
-        return i18n("Updating to the next major version");
+        return i18n("Updating to the next major version. Please be patient as progress is not reported.");
         break;
     case Operation::Unknown:
         return i18n("Operation in progress (started outside of Discover)");
@@ -406,3 +415,5 @@ QVariant RpmOstreeTransaction::icon() const
 {
     return QStringLiteral("application-x-rpm");
 }
+
+#include "moc_RpmOstreeTransaction.cpp"
